# Autoderm's Official SDK Client

## What is Autoderm?

Autoderm offers expertise in dermatology, having our AI models CE marked class 1 as medical devices. Our AI models, built on advanced deep learning, screens for 73 different skin diseases types with exceptional accuracy. Our versatile API seamlessly integrates into your platform, or your workflow from your web browser, offering a user-friendly experience and empowering you with reliable dermatology analytics. Trained over a million smartphone images, our models represent 90% of common public skin concerns, ensuring comprehensive coverage.

## Get Started

Get your API key by signing up at https://autoderm.ai/login_page.html

On the free plan, you are limited to 10 API calls a day, please consider upgrading to use more. Available plans are at https://autoderm.ai/pricing.html

